@@ -30,6 +30,7 @@
 #include "root.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
+#include "misc/misc_conf.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
 #endif /* G_OS_WIN32 */
@@ -1225,6 +1226,58 @@ command_all (gpointer   callback_data,
 }
 
 
+static void
+command_conf_ok (GtkWidget *widget,
+                 GtkWidget *dialog)
+{
+  gint i;
+  GList *glist;
+  GtkWidget *menu_shell;
+
+  history = misc_conf_get_history (MISC_CONF (dialog));
+  newfile = misc_conf_get_newfile (MISC_CONF (dialog));
+  second = misc_conf_get_second (MISC_CONF (dialog));
+  misc_conf_get_size (MISC_CONF (dialog), &def_width, &def_height);
+  n_pos = misc_conf_get_tab (MISC_CONF (dialog));
+  gtk_widget_destroy (dialog);
+  /* ja:履歴の整理 */
+  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
+  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+  for (i = g_list_length (glist) - 3;
+                            i > history- (history == 0) + MENUFILE - 2; i--)
+    gtk_container_remove (GTK_CONTAINER (menu_shell),
+                                                g_list_nth_data (glist, i));
+  g_list_free (glist);
+  /* ja:ノートの位置 */
+  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), n_pos);
+}
+
+
+void
+command_conf (gpointer   callback_data,
+              guint      callback_action,
+              GtkWidget *widget)
+{
+  GtkWidget *dialog;
+
+  dialog = misc_conf_new ();
+  g_signal_connect (G_OBJECT (dialog), "destroy",
+                                            G_CALLBACK (gtk_main_quit), NULL);
+  g_signal_connect (G_OBJECT (MISC_CONF (dialog)->ok_button),
+                            "clicked", G_CALLBACK (command_conf_ok), dialog);
+  g_signal_connect_swapped (G_OBJECT (MISC_CONF (dialog)->cancel_button),
+            "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
+  misc_conf_set_history (MISC_CONF(dialog), history);
+  misc_conf_set_newfile (MISC_CONF(dialog), newfile);
+  misc_conf_set_second (MISC_CONF(dialog), second);
+  misc_conf_set_size (MISC_CONF(dialog), def_width, def_height);
+  misc_conf_set_tab (MISC_CONF(dialog), n_pos);
+  gtk_widget_show (dialog);
+  gtk_grab_add (dialog);
+  gtk_main ();
+}
+
+
 void
 command_charset (gpointer   callback_data,
                  guint      callback_action,
