@@ -29,6 +29,7 @@
 #include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
+#include "misc/misc_accel.h"
 #include "misc/misc_comm.h"
 #include "misc/profile.h"
 
@@ -81,6 +82,7 @@ main (int argc, char *argv[])
   gint i, j, count;
   MmaidWindow *mmaid = NULL;
   Profile *profile;
+  GObject *accel;
   GtkAccelGroup *accel_group;
   GtkWidget *menu_bar, *menu_shell, *menu_item;
   GtkWidget *handle, *toolbar, *vbox;
@@ -398,10 +400,12 @@ MMAID_COPYRIGHT_NOTICE"\n"
                                                                 NULL, NULL);
   gtk_item_factory_create_items (ifactory_menu,
         sizeof(menu_items) / sizeof (GtkItemFactoryEntry), menu_items, NULL);
-  g_signal_connect_after (G_OBJECT (window), "key-press-event",
-                                        G_CALLBACK (signal_key_press), NULL);
   gtk_widget_add_events (window, GDK_KEY_PRESS_MASK);
   menu_bar = gtk_item_factory_get_widget (ifactory_menu, "<main>");
+  /* ja:アクセルグループ */
+  accel = misc_accel_new ();
+  misc_accel_set_window (MISC_ACCEL (accel), GTK_WINDOW (window));
+  misc_accel_add_accel_group (MISC_ACCEL (accel), accel_group);
   /* ja:ツールバー */
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
