@@ -343,68 +343,6 @@ signal_selection_recv (GObject   *object,
 * ja:シグナル/イベント関数群(メイン)                                          *
 *                                                                             *
 ******************************************************************************/
-gboolean
-signal_key_press (GtkWidget   *widget,
-                  GdkEventKey *event,
-                  gpointer    user_data)
-{
-    const struct {
-        gchar *path;
-        gchar *accelerator;
-        GtkItemFactoryCallback callback;
-    } menu_accel[] = {
-            {"<main>/File/New",        "<control>n",        command_new},
-            {"<main>/File/Open...",    "<control>o",        command_open},
-            {"<main>/File/Close",      "<control>w",        command_close},
-            {"<main>/File/Save",       "<control>s",        command_save},
-            {"<main>/File/Reload...",  "<control>r",        command_reload},
-            {"<main>/File/Export...",  "<control>e",        command_export},
-            {"<main>/File/Exit",       "<control>q",        command_exit},
-            {"<main>/Tag/Root...",     "<control>h",        command_root},
-            {"<main>/Tag/Refresh...",  "F5",                command_refresh},
-            {"<main>/Tag/Add...",      "Insert",            command_add},
-            {"<main>/Tag/Edit...",     "<control>Return",   command_edit},
-            {"<main>/Tag/Search...",   "<control>f",        command_search},
-            {"<main>/Tag/Cut",         "<control>x",        command_cut},
-            {"<main>/Tag/Copy",        "<control>c",        command_copy},
-            {"<main>/Tag/Paste",       "<control>v",        command_paste},
-            {"<main>/Tag/Delete",      "Delete",            command_delete},
-            {"<main>/Tag/All",         "<control>a",        command_all},
-            {"<main>/Tag/All",         "<control><shift>a", command_all},
-            {NULL,                     NULL,                NULL}};
-  gint i;
-
-  for (i = 0; menu_accel[i].path; i++)
-    {
-      guint key;
-      GdkModifierType mods;
-
-      gtk_accelerator_parse (menu_accel[i].accelerator, &key, &mods);
-      if (gdk_keyval_to_upper (event->keyval) == gdk_keyval_to_upper (key)
-                                                    && event->state == mods)
-        {
-          GtkWidget *widget;
-
-          widget = gtk_item_factory_get_widget (ifactory_menu,
-                                                        menu_accel[i].path);
-          if (widget)
-            {
-              while (widget && GTK_WIDGET_IS_SENSITIVE (widget))
-                widget = GTK_IS_MENU (widget)
-                            ? gtk_menu_get_attach_widget (GTK_MENU (widget))
-                            : gtk_widget_get_parent (widget);
-              if (!widget)
-                {
-                  menu_accel[i].callback (NULL, 0, NULL);
-                  return TRUE;
-                }
-            }
-        }
-    }
-  return FALSE;
-}
-
-
 gboolean
 signal_delete (GtkWidget *widget,
                GdkEvent  *event,
