@@ -107,12 +107,6 @@ signal_selection_recv (GObject   *object,
 * ja:シグナル/イベント関数群(メイン)                                          *
 *                                                                             *
 ******************************************************************************/
-gboolean
-signal_key_press (GtkWidget   *widget,
-                  GdkEventKey *event,
-                  gpointer     user_data);
-
-
 gboolean
 signal_delete (GtkWidget *widget,
                GdkEvent  *event,
